import * as tslib_1 from "tslib";
import { Library } from '@lovelidge/ln-core';
import { Base } from './base';
import { Option } from './option';
import { ColumnType } from './column';
import * as moment from 'moment';
import * as $ from 'jquery';
var Table = (function (_super) {
    tslib_1.__extends(Table, _super);
    function Table(options, columns) {
        if (columns === void 0) { columns = []; }
        var _this = _super.call(this, options) || this;
        /**
         * Public Variables
         * @type {boolean}
         */
        _this.visible = false;
        //
        // Setup Options
        //
        _this.options = new Option(Object.assign({}, options));
        //
        // Setup Columns
        //
        _this.columns = columns;
        return _this;
    }
    Object.defineProperty(Table.prototype, "options", {
        /**
         * options
         * @returns {any}
         */
        get: function () {
            return this._options;
        },
        /**
         * options
         * @param Option
         */
        set: function (options) {
            if (Library.isObject(options)) {
                this._options = options;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Table.prototype, "items", {
        /**
         * items
         * @returns {Array<Name>}
         */
        get: function () {
            return this._items;
        },
        /**
         * items
         * @param items
         */
        set: function (items) {
            var _this = this;
            if (Library.isArrayWithLength(items)) {
                this._items = items.sort(function (a, b) {
                    return _this.compare(a, b, _this.options.sortBy);
                });
                this.render();
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Table.prototype, "columns", {
        /**
         * items
         * @returns {Array<Item>}
         */
        get: function () {
            return this._columns;
        },
        /**
         * columns
         * @param columns
         */
        set: function (columns) {
            var _this = this;
            if (Library.isArrayWithLength(columns)) {
                this._columns = columns.sort(function (a, b) {
                    return _this.compare(a, b, _this.options.orderBy);
                });
            }
        },
        enumerable: true,
        configurable: true
    });
    /**
     * SortBy
     * @param column
     * @constructor
     */
    Table.prototype.Sortby = function (column, ascending) {
        var _this = this;
        if (ascending === void 0) { ascending = true; }
        if (Library.isStringWithLength(column)) {
            this._items = this._items.sort(function (a, b) {
                return _this.compare(a, b, column.toLowerCase(), ascending);
            });
            this.render();
        }
    };
    /**
     * Render()
     */
    Table.prototype.render = function () {
        var _this = this;
        //
        // Get Table Container
        //
        var container = document.getElementById(this.options.containerId);
        var tbl = document.createElement('table');
        var tblBody = document.createElement('tbody');
        var tblHead = document.createElement('thead');
        //
        // Clear Container
        //
        $(container).empty();
        //
        // Iterate through Object Properties
        //
        this.columns
            .filter(function (column) { return column.visible; })
            .forEach(function (column) {
            var th = document.createElement('th');
            th.innerHTML = "" + column.label;
            //
            // If the OnClick Function is Defiend
            //
            if (Library.isFunction(column.onClick)) {
                th.addEventListener('click', column.onClick);
            }
            tblHead.appendChild(th);
        });
        tblHead.className = 'table-inverse';
        tbl.appendChild(tblHead);
        //
        // Table Attributes
        //
        tbl.className = 'table table-bordered table-striped';
        //
        // Loop Through Names
        //
        this.items.forEach(function (name) {
            //
            // Create Row
            //
            var tr = document.createElement('tr');
            //
            // Iterate through Object Properties
            //
            var node = document.createTextNode('');
            //
            // Filter the Visible Columns
            //
            _this.columns
                .filter(function (column) { return column.visible; })
                .forEach(function (column) {
                var td = document.createElement('td');
                switch (column.type) {
                    case ColumnType.DateTime:
                        node = document.createTextNode(moment(new Date("" + name[column.field])).format('MM/DD/YYYY'));
                        break;
                    default:
                        node = document.createTextNode("" + name[column.field]);
                        break;
                }
                td.appendChild(node);
                tr.appendChild(td);
            });
            //
            // Append Row
            //
            tblBody.appendChild(tr);
        });
        tbl.appendChild(tblBody);
        container.appendChild(tbl);
    };
    /**
     * compare()
     * @param a
     * @param b
     * @param prop
     * @returns {number}
     */
    Table.prototype.compare = function (a, b, prop, ascending) {
        if (ascending === void 0) { ascending = true; }
        if (ascending) {
            if (a[prop] > b[prop]) {
                return 1;
            }
            if (a[prop] < b[prop]) {
                return -1;
            }
        }
        else {
            if (a[prop] < b[prop]) {
                return 1;
            }
            if (a[prop] > b[prop]) {
                return -1;
            }
        }
        return 0;
    };
    return Table;
}(Base));
export { Table };
//# sourceMappingURL=/Users/admin/Desktop/git/public/ln-typescript-2.0-template/src/model/table.js.map